This function loads a pagoo pangenome from a `.RDS` file generated by the `save_pangenomeRDS` method. Objects loaded by this functions keep their states, i.e : dropped/recovered organisms are conserved, as well as the `core_level` setted when the object was originally saved.
load_pangenomeRDS(file, pkg, ...)A PgR6MS class object, or a PgR6M object (with or
without sequences, respectively).
The path to the pangenome `.RDS` file.
The package to use to load the object. Shouldn't be necessary to provide, but may be useful in some cases.
Arguments to be passed to the pagoo object. sep and
core_level overwrite the values stored in the file.